@@ -21,8 +21,7 @@ class packwiz(Writer):
 
     def add_resource(self, resource: Resource) -> None:
 
-        if not resource.providers: 
-            self.add_override(resource.file); return
+        if not resource.providers: return self.add_override(resource.file)
     
         data = {
             "name": resource.name,
