@@ -9,7 +9,7 @@ from urllib.parse import urlparse
 
 import keyring as secret_store
 from aiohttp_client_cache.session import CachedSession
-from tomli import loads as parse_toml
+from pytoml import loads as parse_toml
 
 from .structures import Intermediate, Resource
 
