@@ -56,7 +56,7 @@ class Parser(Format):
             name = path.name,
             hash = File.Hash(sha256=get_hash(path)),
             path = path,
-            relativePath = relative_path.name)
+            relativePath = relative_path.as_posix())
         
         self.intermediate.overrides.append(file)
 
@@ -72,6 +72,7 @@ class Parser(Format):
 
         for file in [file for file in self.temp_dir.glob("**/*") if file.is_file()]:
             if file.parent.name in downloadable_content and file.suffix != ".txt": 
+                if file.suffix == ".disabled": continue
                 self.resourceAPI.queue_resource(file)
             else: overrides.append(file)
 
